package com.nto.presentation

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.viewModels
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.toArgb
import androidx.navigation.compose.rememberNavController
import com.nto.presentation.composable.Navigation
import com.nto.presentation.screens.splashScreen.SplashScreenViewModel
import com.nto.presentation.theme.NTOTheme
import com.nto.presentation.theme.TextColor
import dagger.hilt.android.AndroidEntryPoint


@AndroidEntryPoint
class MainActivity : ComponentActivity() {
    val viewmodel by viewModels<SplashScreenViewModel>()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        this.window.statusBarColor = TextColor.toArgb()
        viewmodel.checkLogin().apply {
            setContent {
                NTOTheme {
                    //XML SUCKS! We use Jetpack Compose btw :>
                    val state = viewmodel.state.collectAsState().value

                    Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                        val navController = rememberNavController()
                        Navigation(
                            navController = navController,
                            modifier = Modifier
                                .padding(innerPadding)
                                .fillMaxSize(),
                            skipAuth = state.skipAuth
                        )
                    }
                }
            }
        }
    }
}
