package com.nto.presentation.screens.loginScreen

import android.content.Context
import android.widget.Toast
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.navigation.NavHostController
import com.nto.data.utils.Destinations
import com.nto.domain.usecase.LoginUseCase
import dagger.hilt.android.lifecycle.HiltViewModel
import dagger.hilt.android.qualifiers.ApplicationContext
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.invoke
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class LoginViewModel @Inject constructor(
    private val useCase: LoginUseCase, @ApplicationContext private val context: Context
) : ViewModel() {
    private val _state = MutableStateFlow(LoginScreenState())

    val state: StateFlow<LoginScreenState>
        get() = _state.asStateFlow()

    fun setEmail(value: String) {
        _state.tryEmit(_state.value.copy(email = value))
        checkInput()
    }

    fun setPassword(value: String) {
        _state.tryEmit(_state.value.copy(password = value))
        checkInput()
    }

    private fun checkInput() {
        val state = _state.value
        val result = useCase.checkCredentials(state.email, state.password)
        _state.tryEmit(_state.value.copy(disabled = !result))
    }

    fun login(navController: NavHostController) {
        viewModelScope.launch(Dispatchers.IO) {
            val state = _state.value
            val result = useCase.auth(state.email, state.password)
            if (result.message != null) {
                Dispatchers.Main {
                    Toast.makeText(context, result.message, Toast.LENGTH_LONG).show()
                }
            }
            if (result.successful) {
                Dispatchers.Main {
                    navController.navigate(Destinations.Profile) {
                        popUpTo<Destinations.Login> {
                            inclusive = true
                        }
                    }
                }
            }
        }
    }
}