package com.nto.presentation.screens.profileScreen

import android.content.Context
import com.nto.data.models.Position
import com.nto.data.models.UserDTO
import com.nto.data.models.cards.VisitCardDTO
import com.nto.presentation.R
import java.time.format.DateTimeFormatter

data class ProfileState(
    var firstName: String = "",
    var secondName: String = "",
    var thirdName: String = "",
    var lastOpen: String = "",
    var job: String = "",
    var isUnauthorized: Boolean = false,
    var visits: List<VisitCardDTO> = listOf()
) {
    fun deserialize(o: UserDTO, context: Context) {
        val dateFormat = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")
        this.firstName = o.firstName
        this.secondName = o.lastName
        this.thirdName = o.patronymic
        this.lastOpen = try {
            o.lastVisit.format(dateFormat)
        } catch (e: NullPointerException) {
            context.getString(R.string.label_last_visit_none)
        }
        this.job = translatePosition(o.position, context)
        this.isUnauthorized = o.isUnauthorized
    }

    private fun translatePosition(position: Position, context: Context): String {
        return when (position) {
            Position.TESTER -> context.getString(R.string.label_tester)
            Position.DEVELOPER -> context.getString(R.string.label_developer)
            Position.DESIGNER -> context.getString(R.string.label_designer)
            Position.ANALYST -> context.getString(R.string.label_analyst)
            Position.ADMINISTRATOR -> context.getString(R.string.label_administrator)
        }
    }
}
