package com.nto.presentation.screens.profileScreen

import android.content.Context
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.navigation.NavController
import com.nto.data.models.QRDTO
import com.nto.data.models.cards.VisitCardDTO
import com.nto.data.models.cards.VisitType
import com.nto.data.utils.Destinations
import com.nto.domain.usecase.ProfileUseCase
import dagger.hilt.android.lifecycle.HiltViewModel
import dagger.hilt.android.qualifiers.ApplicationContext
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.invoke
import kotlinx.coroutines.launch
import java.time.LocalDateTime
import javax.inject.Inject

@HiltViewModel
class ProfileViewModel @Inject constructor(
    private val useCase: ProfileUseCase, @ApplicationContext private val context: Context
) : ViewModel() {
    private var _isLoading by mutableStateOf(false)
    private val _state = MutableStateFlow(ProfileState())

    val isLoading get() = _isLoading
    val state: StateFlow<ProfileState>
        get() = _state.asStateFlow()

    fun updateInfo() {
        viewModelScope.launch(Dispatchers.IO) {
            _isLoading = true
            val result = useCase.getInfo()
            val visitsResult = useCase.getVisits()
            _state.tryEmit(ProfileState().apply {
                deserialize(result, context)
                if(!visitsResult.isError) {
                    visits = visitsResult.data!!
                }
            })
            _isLoading = false
        }
    }

    fun admin(navController: NavController) {
        //TODO
    }

    fun logout(navController: NavController) {
        viewModelScope.launch(Dispatchers.IO) {
            useCase.logout()
            Dispatchers.Main {
                navController.navigate(Destinations.Login) {
                    popUpTo<Destinations.Profile> {
                        inclusive = true
                    }
                }
            }
        }
    }

    fun option(navController: NavController) {
        navController.navigate(Destinations.Options)
    }

    init {
        updateInfo()
    }
}