package com.nto.presentation.screens.scanResult

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.gestures.snapping.SnapPosition
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.OutlinedButton
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.DefaultShadowColor
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import com.nto.data.utils.Destinations
import com.nto.presentation.R
import com.nto.presentation.theme.NTOTheme
import com.nto.presentation.theme.playfair
import com.nto.presentation.theme.raleway

@Composable
fun ScanResultScreen(
    navController: NavController,
    modifier: Modifier = Modifier,
    viewModel: ScanResultViewModel = hiltViewModel()
) {
    val state by viewModel.state.collectAsState()
    Scaffold(bottomBar = {
        val buttonColor = when (state) {
            ScanResultState.Success -> NTOTheme.colors.button
            ScanResultState.Error -> NTOTheme.colors.buttonAdmin
            ScanResultState.Warning -> NTOTheme.colors.warning
        }
        OutlinedButton(
            onClick = {
                navController.navigate(Destinations.Profile) {
                    popUpTo<Destinations.Scan> {
                        inclusive = true
                    }
                }
            },
            shape = RoundedCornerShape(10.dp),
            colors = ButtonDefaults.outlinedButtonColors(
                contentColor = buttonColor,
                containerColor = Color.Transparent
            ),
            border = BorderStroke(width = 2.dp, color = buttonColor),
            modifier = Modifier.padding(horizontal = 24.dp, vertical = 32.dp)
                .fillMaxWidth()
                .height(62.dp)
        ) {
            Text(
                text = stringResource(R.string.close),
                fontSize = 14.sp,
                fontWeight = FontWeight.SemiBold
            )
        }
    }) { paddingValues ->
        Column(
            Modifier
                .padding(paddingValues)
                .fillMaxSize(),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center
        ) {
            Image(
                painter = painterResource(
                    id = when (state) {
                        ScanResultState.Success -> R.drawable.ic_scan_success
                        ScanResultState.Error -> R.drawable.ic_scan_error
                        ScanResultState.Warning -> R.drawable.ic_scan_warning
                    }
                ), contentDescription = ""
            )
            Text(
                text = stringResource(R.string.code_scanned),
                fontFamily = playfair,
                fontSize = 36.sp,
                color = NTOTheme.colors.primaryText
            )
            Spacer(Modifier.height(8.dp))
            Text(
                text = stringResource(
                    when (state) {
                        ScanResultState.Success -> R.string.code_scanned_success
                        ScanResultState.Error -> R.string.code_scanned_error
                        ScanResultState.Warning -> R.string.code_scanned_warning
                    }
                ),
                fontSize = 20.sp,
                fontWeight = FontWeight.Medium,
                color = NTOTheme.colors.primaryText,
                fontFamily = raleway
            )
            Spacer(Modifier.height(60.dp))
        }
    }
}